#[element]Expand description
Sets the required values and traits for a struct to be a element. You will still need to implement ElementCore yourself
#[element]Sets the required values and traits for a struct to be a element. You will still need to implement ElementCore yourself